#include "config_menu.h"
#include "lcd_routines.h"
#include "debouncing.h"
#include "shutter.h"
#include "time.h"
#include "dcf77.h"

#include <stdlib.h>
#include <avr/interrupt.h>
#include <util/delay.h>

void menu_init() {
	menu_active = 0;
	menu_flash_state = 0;
}

void menu_open() {
	// Variablen zurck setzen
	time_load_eeprom();
	// DCF deaktivieren
	dcf_sync = 0;

	lcd_clear();
	lcd_setcursor(5, 1);
	lcd_string("MENU");
	_delay_ms(2000);
	lcd_clear();
	menu_up_hour_flash();
	// Men als aktiv melden
	menu_active = 1;

}

void menu_up_hour_flash() {
	if (cache_sec != seconds) {
		cache_sec = seconds;
		menu_flash_state = !menu_flash_state;
	}
	lcd_setcursor(1, 1);
	lcd_string("UP - Time:");
	if (menu_flash_state) {
		itoa(shutter_up_hourdd, menu_tmp_char, 10);
		lcd_setcursor(1, 2);
		if (shutter_up_hourdd <= 9) {
			lcd_data('0');
		}
		lcd_string(menu_tmp_char);
	} else {
		lcd_setcursor(1, 2);
		lcd_string("  ");
	}
	itoa(shutter_up_minute, menu_tmp_char, 10);
	lcd_data(':');
	if (shutter_up_minute < 10) {
		lcd_data('0');
	}
	lcd_string(menu_tmp_char);
	_delay_ms(200);
}

void menu_up_minute_flash() {
	if (cache_sec != seconds) {
		cache_sec = seconds;
		menu_flash_state = !menu_flash_state;
	}
	lcd_setcursor(1, 1);
	lcd_string("UP - Time:");

	itoa(shutter_up_hourdd, menu_tmp_char, 10);
	lcd_setcursor(1, 2);
	if (shutter_up_hourdd <= 9) {
		lcd_data('0');
	}
	lcd_string(menu_tmp_char);

	if (menu_flash_state) {
		itoa(shutter_up_minute, menu_tmp_char, 10);
		lcd_data(':');
		if (shutter_up_minute < 10) {
			lcd_data('0');
		}
		lcd_string(menu_tmp_char);
	} else {
		lcd_setcursor(4, 2);
		lcd_string("  ");
	}
	_delay_ms(200);
}

void menu_down_hour_flash() {
	if (cache_sec != seconds) {
		cache_sec = seconds;
		menu_flash_state = !menu_flash_state;
	}
	lcd_setcursor(1, 1);
	lcd_string("DOWN - Time:");
	if (menu_flash_state) {
		itoa(shutter_down_hour, menu_tmp_char, 10);
		lcd_setcursor(1, 2);
		if (shutter_down_hour < 10) {
			lcd_data('0');
		}
		lcd_string(menu_tmp_char);
	} else {
		lcd_setcursor(1, 2);
		lcd_string("  ");
	}
	itoa(shutter_down_minute, menu_tmp_char, 10);
	lcd_data(':');
	if (shutter_down_minute < 10) {
		lcd_data('0');
	}
	lcd_string(menu_tmp_char);
	_delay_ms(200);
}

void menu_down_minute_flash() {
	if (cache_sec != seconds) {
		cache_sec = seconds;
		menu_flash_state = !menu_flash_state;
	}
	lcd_setcursor(1, 1);
	lcd_string("DOWN - Time:");

	itoa(shutter_down_hour, menu_tmp_char, 10);
	lcd_setcursor(1, 2);
	if (shutter_down_hour < 10) {
		lcd_data('0');
	}
	lcd_string(menu_tmp_char);

	if (menu_flash_state) {
		itoa(shutter_down_minute, menu_tmp_char, 10);
		lcd_data(':');
		if (shutter_down_minute < 10) {
			lcd_data('0');
		}
		lcd_string(menu_tmp_char);
	} else {
		lcd_setcursor(4, 2);
		lcd_string("  ");
	}
	_delay_ms(200);
}

void menu_save_question() {
	lcd_setcursor(1, 1);
	lcd_string("Save?        ");
	lcd_setcursor(1, 2);
	lcd_string(" YES      NO");
}

void menu_asker() {

	if (menu_active) {
		// Durchscrollen
		if (get_key_short(1 << KEY0)) {
			switch (menu_active) {
			case 5:
				menu_close();
				return;
			default:
				menu_active++;
				return;
			}

		}

		// Wert erhhen
		if (get_key_short(1 << KEY1) || get_key_rpt(1 << KEY1)) {
			switch (menu_active) {
			case 1:
				if (shutter_up_hourdd <= 22) {
					shutter_up_hourdd++;
				} else {
					shutter_up_hourdd = 0;
				}
				return;
			case 2:
				if (shutter_up_minute <= 50) {
					shutter_up_minute += 5;
				} else {
					shutter_up_minute = 0;
				}
				return;
			case 3:
				if (shutter_down_hour <= 22) {
					shutter_down_hour++;
				} else {
					shutter_down_hour = 0;
				}
				return;
			case 4:
				if (shutter_down_minute <= 50) {
					shutter_down_minute += 5;
				} else {
					shutter_down_minute = 0;
				}
				return;
			case 5:
				menu_active = 1;
				lcd_clear();
				_delay_ms(500);
				return;
			default:
				menu_active = 1;
				lcd_clear();
				_delay_ms(3000);
				return;
			}
		}

		switch (menu_active) {
		case 1:
			menu_up_hour_flash();
			return;
		case 2:
			menu_up_minute_flash();
			return;
		case 3:
			menu_down_hour_flash();
			return;
		case 4:
			menu_down_minute_flash();
			return;
		case 5:
			menu_save_question();
			return;
		default:
			menu_active = 1;
			lcd_clear();
			_delay_ms(3000);
			return;

		}

	} else {
		// Men starten
		if (get_key_long(1 << KEY0) && get_key_long(1 << KEY1)) {
			if (shutter_working) {
				shutter_stop();
			}
			menu_open();
			_delay_ms(200);
			get_key_rpt(1<<KEY1); // sorgt dafr dass werte nich voreilig hoch gezhlt werden
		}

	}

}

void menu_close() {
	lcd_clear();
	// Variablen schreiben
	time_save_eeprom();
	// einen Sync veranlassen
	dcf_sync = DCF_SYNC_PERIODE;
	// Menu als deaktiviert markieren
	menu_active = 0;
}
