#include "prop.h"
#include "debouncing.h"
#include "light.h"
#include "lcd_routines.h"
#include "time.h"
#include "dcf77.h"
#include "shutter.h"
#include "config_menu.h"

#include <stdlib.h>
#include <avr/interrupt.h>

void controller_init() {
	// Relais an Port B0 & B1 (Ausgang)
	SWTH_DDR = 0xFF;
	//FIXME nur fr test
	SWTH_PORT = 0xFF; // init dass andere ports hiegh sind
	SWTH_PORT &= ~(ALL_SWTH); // Init auf low (fuer led)

	// Schalter an Port D0 & D1 &D2(Eingang mit internem Pullup)
	KEY_DDR &= ~(ALL_KEYS); // configure key port for input
	KEY_PORT = ALL_KEYS; // turn on pull up resistors for keys

	// Aktiviere Timer0 fr Entprellung
	TCCR0 = (1 << CS02) | (1 << CS00); // divide by 1024
	TIMSK = 1 << TOIE0; // Aktiviert den Overflowinterrupt

	// Aktiviere Timer1 fr Zeitermessung
	TCCR1B = (1 << CS10) | (1 << WGM12); // Vorteiler 1, CTC Modus
	TIMSK |= 1 << OCIE1A; // Compare A Interrupt ZUSTZLICH aktivieren
	OCR1A = 39999; // Comparewert auf 39999 so gibt es alle 400000 Zyklen ein Interrupt (alle 0,01)

	// initialisierungen der Zusatzfunktionen
	debouncing_init();
	light_init();
	lcd_init();
	time_init();
	dcf_init();
	menu_init();
}

ISR ( DCF_ISR )
{
	dcf_INT_Routine();

}

// Timerinterrupt Debounceing & DFC
ISR( TIMER0_OVF_vect )
{ // 100 Interrupts/sec bei 4mhz
	// BEGIN: debouncing
	debouncing_ISRoutine();
	// END: debouncing

	// BEGIN: DCF auslesen
	dcf_ISRoutine();
	// END: DFC auslesen
}

// Timerinterrupt Zeitmessung
ISR ( TIMER1_COMPA_vect )
{

	if (interrupts < 99) { // alle 100 Interrupts ist eine Sekunde vorbei (bei 4Mhz)
		interrupts++;
	} else { // sekunde vorbei
		interrupts = 0;
		time_count();
	}

}

int main(void) {
	controller_init();
	//	char tmp[3];

	while (1) {
		if (!menu_active) {
			light_asker();
			shutter_asker();
			time_display();
			/*
			 itoa(shutter_down, tmp,10);
			 set_cursor(0,1);
			 lcd_string(tmp);

			 itoa(shutter_up, tmp,10);
			 set_cursor(2,1);
			 lcd_string(tmp);
			 */
		}

		menu_asker();
	}

	return 0; //wird nie erreicht
}
