#include "time.h"

#include <stdlib.h>
#include "lcd_routines.h"
#include "shutter.h"
#include "dcf77.h"

#include <avr/eeprom.h>

// EEPROM Speicher-Variablen
uint8_t eeShutter_up_hour EEMEM = 5;
uint8_t eeShutter_down_hour EEMEM = 17;
uint8_t eeShutter_up_minute EEMEM = 30;
uint8_t eeShutter_down_minute EEMEM = 15;

// initialisiert die Zeitvariablen
void time_init() {
	interrupts = 0;
	seconds = 0;
	minutes = 0;
	hours = 0;

	cache_sec = 0;
	dot_on = 0;

	shutter_up = 0;
	shutter_down = 0;

	time_load_eeprom();

	// DCF Sync immer um 3 Uhr
	dcf_sync_hour = 3;
	dcf_sync_minute = 0;
}

void time_load_eeprom() {
	shutter_up_hourdd = eeprom_read_byte(&eeShutter_up_hour);
	shutter_down_hour = eeprom_read_byte(&eeShutter_down_hour);
	shutter_up_minute = eeprom_read_byte(&eeShutter_up_minute);
	shutter_down_minute = eeprom_read_byte(&eeShutter_down_minute);
}

void time_save_eeprom() {
	eeprom_write_byte(&eeShutter_up_hour, shutter_up_hourdd);
	eeprom_write_byte(&eeShutter_down_hour, shutter_down_hour);
	eeprom_write_byte(&eeShutter_up_minute, shutter_up_minute);
	eeprom_write_byte(&eeShutter_down_minute, shutter_down_minute);
}

// Zhlt um eine Sekunde hoch
void time_count() {
	event_counter();
	if (seconds < 59) {
		seconds++;
	} else {
		seconds = 0;
		if (minutes < 59) {
			minutes++;

			//Quickfix
			lcd_clear();

			// Eventzeiten prhfen
			check_events();

		} else {
			minutes = 0;
			if (hours < 24) {
				hours++;
			} else {
				hours = 0;
			}
		}
	}

}

// Zeigt die Uhrzeit auf dem LCD an
void time_display() {
	// TODO repaints von status oder hnlichem

	if (cache_sec != seconds) { // nur einmal pro secunde Painten
		cache_sec = seconds;

		if (dcf_sync) {
			lcd_setcursor(4, 1);
			lcd_string("DCF SYNC");
			return;
		}

		itoa(minutes, min_char, 10);
		itoa(hours, hrs_char, 10);

		// Stunden
		lcd_setcursor(5, 1);
		if (hours < 10) {
			lcd_data('0');
		}
		lcd_string(hrs_char);

		// Blinkender Doppelpunkt
		//set_cursor(7, 1);
		if (!dot_on) {
			lcd_data(':');
			dot_on = 1;
		} else {
			lcd_data(' ');
			dot_on = 0;
		}

		// Minuten
		lcd_setcursor(8, 1);
		if (minutes < 10) {
			lcd_data('0');
		}
		lcd_string(min_char);
		/*
		 char sec_char[3];
		 itoa(seconds,sec_char,10);
		 lcd_string(" ");
		 lcd_string(sec_char);
		 */
	}
}

// berprhft ob es Zeit fr ein Event ist
void check_events() {

	if (hours == shutter_up_hourdd || hours == shutter_down_hour || hours
			== dcf_sync_hour) { // Wenn die Minute fr irgend ein Event geschlagen hat
		// dann prhfe die Stunden der einzelnen Events
		if (minutes == shutter_up_minute) {
			shutter_up = SHUTTER_UP_PERIODE;
		}
		if (minutes == shutter_down_minute) {
			shutter_down = SHUTTER_DOWN_PERIODE;
		}
		if (minutes == dcf_sync_minute) {
			// Anz der Syncs und Interrupt aktivieren
			dcf_sync = DCF_SYNC_PERIODE;
			GIMSK |= (1 << INT1);
		}
	}

}

// dekrementiert die Eventdauer bis sie false ist
void event_counter() {
	if (shutter_up) {
		shutter_up--;
	}
	if (shutter_down) {
		shutter_down--;
	}
}

